@@ -1,7 +1,7 @@
 """
 Type annotations for chime-sdk-messaging service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/literals/)
 
 Usage::
 
@@ -35,6 +35,7 @@ __all__ = (
     "ChimeSDKMessagingServiceName",
     "ServiceName",
     "ResourceServiceName",
+    "RegionName",
 )
 
 
@@ -185,6 +186,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -382,3 +384,4 @@ ResourceServiceName = Literal[
     "sns",
     "sqs",
 ]
+RegionName = Literal["us-east-1"]
