@@ -1,7 +1,7 @@
 """
 Type annotations for chime-sdk-messaging service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/type_defs/)
 
 Usage::
 
@@ -157,9 +157,10 @@ __all__ = (
 AppInstanceUserMembershipSummaryTypeDef = TypedDict(
     "AppInstanceUserMembershipSummaryTypeDef",
     {
-        "Type": NotRequired[ChannelMembershipTypeType],
-        "ReadMarkerTimestamp": NotRequired[datetime],
+        "Type": ChannelMembershipTypeType,
+        "ReadMarkerTimestamp": datetime,
     },
+    total=False,
 )
 
 AssociateChannelFlowRequestRequestTypeDef = TypedDict(
@@ -174,31 +175,47 @@ AssociateChannelFlowRequestRequestTypeDef = TypedDict(
 BatchChannelMembershipsTypeDef = TypedDict(
     "BatchChannelMembershipsTypeDef",
     {
-        "InvitedBy": NotRequired["IdentityTypeDef"],
-        "Type": NotRequired[ChannelMembershipTypeType],
-        "Members": NotRequired[List["IdentityTypeDef"]],
-        "ChannelArn": NotRequired[str],
+        "InvitedBy": "IdentityTypeDef",
+        "Type": ChannelMembershipTypeType,
+        "Members": List["IdentityTypeDef"],
+        "ChannelArn": str,
     },
+    total=False,
 )
 
 BatchCreateChannelMembershipErrorTypeDef = TypedDict(
     "BatchCreateChannelMembershipErrorTypeDef",
     {
-        "MemberArn": NotRequired[str],
-        "ErrorCode": NotRequired[ErrorCodeType],
-        "ErrorMessage": NotRequired[str],
+        "MemberArn": str,
+        "ErrorCode": ErrorCodeType,
+        "ErrorMessage": str,
     },
+    total=False,
 )
 
-BatchCreateChannelMembershipRequestRequestTypeDef = TypedDict(
-    "BatchCreateChannelMembershipRequestRequestTypeDef",
+_RequiredBatchCreateChannelMembershipRequestRequestTypeDef = TypedDict(
+    "_RequiredBatchCreateChannelMembershipRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "MemberArns": Sequence[str],
         "ChimeBearer": str,
-        "Type": NotRequired[ChannelMembershipTypeType],
     },
 )
+_OptionalBatchCreateChannelMembershipRequestRequestTypeDef = TypedDict(
+    "_OptionalBatchCreateChannelMembershipRequestRequestTypeDef",
+    {
+        "Type": ChannelMembershipTypeType,
+    },
+    total=False,
+)
+
+
+class BatchCreateChannelMembershipRequestRequestTypeDef(
+    _RequiredBatchCreateChannelMembershipRequestRequestTypeDef,
+    _OptionalBatchCreateChannelMembershipRequestRequestTypeDef,
+):
+    pass
+
 
 BatchCreateChannelMembershipResponseTypeDef = TypedDict(
     "BatchCreateChannelMembershipResponseTypeDef",
@@ -212,40 +229,57 @@ BatchCreateChannelMembershipResponseTypeDef = TypedDict(
 ChannelAssociatedWithFlowSummaryTypeDef = TypedDict(
     "ChannelAssociatedWithFlowSummaryTypeDef",
     {
-        "Name": NotRequired[str],
-        "ChannelArn": NotRequired[str],
-        "Mode": NotRequired[ChannelModeType],
-        "Privacy": NotRequired[ChannelPrivacyType],
-        "Metadata": NotRequired[str],
+        "Name": str,
+        "ChannelArn": str,
+        "Mode": ChannelModeType,
+        "Privacy": ChannelPrivacyType,
+        "Metadata": str,
     },
+    total=False,
 )
 
 ChannelBanSummaryTypeDef = TypedDict(
     "ChannelBanSummaryTypeDef",
     {
-        "Member": NotRequired["IdentityTypeDef"],
+        "Member": "IdentityTypeDef",
     },
+    total=False,
 )
 
 ChannelBanTypeDef = TypedDict(
     "ChannelBanTypeDef",
     {
-        "Member": NotRequired["IdentityTypeDef"],
-        "ChannelArn": NotRequired[str],
-        "CreatedTimestamp": NotRequired[datetime],
-        "CreatedBy": NotRequired["IdentityTypeDef"],
+        "Member": "IdentityTypeDef",
+        "ChannelArn": str,
+        "CreatedTimestamp": datetime,
+        "CreatedBy": "IdentityTypeDef",
     },
+    total=False,
 )
 
-ChannelFlowCallbackRequestRequestTypeDef = TypedDict(
-    "ChannelFlowCallbackRequestRequestTypeDef",
+_RequiredChannelFlowCallbackRequestRequestTypeDef = TypedDict(
+    "_RequiredChannelFlowCallbackRequestRequestTypeDef",
     {
         "CallbackId": str,
         "ChannelArn": str,
         "ChannelMessage": "ChannelMessageCallbackTypeDef",
-        "DeleteResource": NotRequired[bool],
     },
 )
+_OptionalChannelFlowCallbackRequestRequestTypeDef = TypedDict(
+    "_OptionalChannelFlowCallbackRequestRequestTypeDef",
+    {
+        "DeleteResource": bool,
+    },
+    total=False,
+)
+
+
+class ChannelFlowCallbackRequestRequestTypeDef(
+    _RequiredChannelFlowCallbackRequestRequestTypeDef,
+    _OptionalChannelFlowCallbackRequestRequestTypeDef,
+):
+    pass
+
 
 ChannelFlowCallbackResponseTypeDef = TypedDict(
     "ChannelFlowCallbackResponseTypeDef",
@@ -259,162 +293,189 @@ ChannelFlowCallbackResponseTypeDef = TypedDict(
 ChannelFlowSummaryTypeDef = TypedDict(
     "ChannelFlowSummaryTypeDef",
     {
-        "ChannelFlowArn": NotRequired[str],
-        "Name": NotRequired[str],
-        "Processors": NotRequired[List["ProcessorTypeDef"]],
+        "ChannelFlowArn": str,
+        "Name": str,
+        "Processors": List["ProcessorTypeDef"],
     },
+    total=False,
 )
 
 ChannelFlowTypeDef = TypedDict(
     "ChannelFlowTypeDef",
     {
-        "ChannelFlowArn": NotRequired[str],
-        "Processors": NotRequired[List["ProcessorTypeDef"]],
-        "Name": NotRequired[str],
-        "CreatedTimestamp": NotRequired[datetime],
-        "LastUpdatedTimestamp": NotRequired[datetime],
+        "ChannelFlowArn": str,
+        "Processors": List["ProcessorTypeDef"],
+        "Name": str,
+        "CreatedTimestamp": datetime,
+        "LastUpdatedTimestamp": datetime,
     },
+    total=False,
 )
 
 ChannelMembershipForAppInstanceUserSummaryTypeDef = TypedDict(
     "ChannelMembershipForAppInstanceUserSummaryTypeDef",
     {
-        "ChannelSummary": NotRequired["ChannelSummaryTypeDef"],
-        "AppInstanceUserMembershipSummary": NotRequired["AppInstanceUserMembershipSummaryTypeDef"],
+        "ChannelSummary": "ChannelSummaryTypeDef",
+        "AppInstanceUserMembershipSummary": "AppInstanceUserMembershipSummaryTypeDef",
     },
+    total=False,
 )
 
 ChannelMembershipPreferencesTypeDef = TypedDict(
     "ChannelMembershipPreferencesTypeDef",
     {
-        "PushNotifications": NotRequired["PushNotificationPreferencesTypeDef"],
+        "PushNotifications": "PushNotificationPreferencesTypeDef",
     },
+    total=False,
 )
 
 ChannelMembershipSummaryTypeDef = TypedDict(
     "ChannelMembershipSummaryTypeDef",
     {
-        "Member": NotRequired["IdentityTypeDef"],
+        "Member": "IdentityTypeDef",
     },
+    total=False,
 )
 
 ChannelMembershipTypeDef = TypedDict(
     "ChannelMembershipTypeDef",
     {
-        "InvitedBy": NotRequired["IdentityTypeDef"],
-        "Type": NotRequired[ChannelMembershipTypeType],
-        "Member": NotRequired["IdentityTypeDef"],
-        "ChannelArn": NotRequired[str],
-        "CreatedTimestamp": NotRequired[datetime],
-        "LastUpdatedTimestamp": NotRequired[datetime],
+        "InvitedBy": "IdentityTypeDef",
+        "Type": ChannelMembershipTypeType,
+        "Member": "IdentityTypeDef",
+        "ChannelArn": str,
+        "CreatedTimestamp": datetime,
+        "LastUpdatedTimestamp": datetime,
     },
+    total=False,
 )
 
-ChannelMessageCallbackTypeDef = TypedDict(
-    "ChannelMessageCallbackTypeDef",
+_RequiredChannelMessageCallbackTypeDef = TypedDict(
+    "_RequiredChannelMessageCallbackTypeDef",
     {
         "MessageId": str,
-        "Content": NotRequired[str],
-        "Metadata": NotRequired[str],
-        "PushNotification": NotRequired["PushNotificationConfigurationTypeDef"],
-        "MessageAttributes": NotRequired[Mapping[str, "MessageAttributeValueTypeDef"]],
     },
 )
+_OptionalChannelMessageCallbackTypeDef = TypedDict(
+    "_OptionalChannelMessageCallbackTypeDef",
+    {
+        "Content": str,
+        "Metadata": str,
+        "PushNotification": "PushNotificationConfigurationTypeDef",
+        "MessageAttributes": Mapping[str, "MessageAttributeValueTypeDef"],
+    },
+    total=False,
+)
+
+
+class ChannelMessageCallbackTypeDef(
+    _RequiredChannelMessageCallbackTypeDef, _OptionalChannelMessageCallbackTypeDef
+):
+    pass
+
 
 ChannelMessageStatusStructureTypeDef = TypedDict(
     "ChannelMessageStatusStructureTypeDef",
     {
-        "Value": NotRequired[ChannelMessageStatusType],
-        "Detail": NotRequired[str],
+        "Value": ChannelMessageStatusType,
+        "Detail": str,
     },
+    total=False,
 )
 
 ChannelMessageSummaryTypeDef = TypedDict(
     "ChannelMessageSummaryTypeDef",
     {
-        "MessageId": NotRequired[str],
-        "Content": NotRequired[str],
-        "Metadata": NotRequired[str],
-        "Type": NotRequired[ChannelMessageTypeType],
-        "CreatedTimestamp": NotRequired[datetime],
-        "LastUpdatedTimestamp": NotRequired[datetime],
-        "LastEditedTimestamp": NotRequired[datetime],
-        "Sender": NotRequired["IdentityTypeDef"],
-        "Redacted": NotRequired[bool],
-        "Status": NotRequired["ChannelMessageStatusStructureTypeDef"],
-        "MessageAttributes": NotRequired[Dict[str, "MessageAttributeValueTypeDef"]],
+        "MessageId": str,
+        "Content": str,
+        "Metadata": str,
+        "Type": ChannelMessageTypeType,
+        "CreatedTimestamp": datetime,
+        "LastUpdatedTimestamp": datetime,
+        "LastEditedTimestamp": datetime,
+        "Sender": "IdentityTypeDef",
+        "Redacted": bool,
+        "Status": "ChannelMessageStatusStructureTypeDef",
+        "MessageAttributes": Dict[str, "MessageAttributeValueTypeDef"],
     },
+    total=False,
 )
 
 ChannelMessageTypeDef = TypedDict(
     "ChannelMessageTypeDef",
     {
-        "ChannelArn": NotRequired[str],
-        "MessageId": NotRequired[str],
-        "Content": NotRequired[str],
-        "Metadata": NotRequired[str],
-        "Type": NotRequired[ChannelMessageTypeType],
-        "CreatedTimestamp": NotRequired[datetime],
-        "LastEditedTimestamp": NotRequired[datetime],
-        "LastUpdatedTimestamp": NotRequired[datetime],
-        "Sender": NotRequired["IdentityTypeDef"],
-        "Redacted": NotRequired[bool],
-        "Persistence": NotRequired[ChannelMessagePersistenceTypeType],
-        "Status": NotRequired["ChannelMessageStatusStructureTypeDef"],
-        "MessageAttributes": NotRequired[Dict[str, "MessageAttributeValueTypeDef"]],
+        "ChannelArn": str,
+        "MessageId": str,
+        "Content": str,
+        "Metadata": str,
+        "Type": ChannelMessageTypeType,
+        "CreatedTimestamp": datetime,
+        "LastEditedTimestamp": datetime,
+        "LastUpdatedTimestamp": datetime,
+        "Sender": "IdentityTypeDef",
+        "Redacted": bool,
+        "Persistence": ChannelMessagePersistenceTypeType,
+        "Status": "ChannelMessageStatusStructureTypeDef",
+        "MessageAttributes": Dict[str, "MessageAttributeValueTypeDef"],
     },
+    total=False,
 )
 
 ChannelModeratedByAppInstanceUserSummaryTypeDef = TypedDict(
     "ChannelModeratedByAppInstanceUserSummaryTypeDef",
     {
-        "ChannelSummary": NotRequired["ChannelSummaryTypeDef"],
+        "ChannelSummary": "ChannelSummaryTypeDef",
     },
+    total=False,
 )
 
 ChannelModeratorSummaryTypeDef = TypedDict(
     "ChannelModeratorSummaryTypeDef",
     {
-        "Moderator": NotRequired["IdentityTypeDef"],
+        "Moderator": "IdentityTypeDef",
     },
+    total=False,
 )
 
 ChannelModeratorTypeDef = TypedDict(
     "ChannelModeratorTypeDef",
     {
-        "Moderator": NotRequired["IdentityTypeDef"],
-        "ChannelArn": NotRequired[str],
-        "CreatedTimestamp": NotRequired[datetime],
-        "CreatedBy": NotRequired["IdentityTypeDef"],
+        "Moderator": "IdentityTypeDef",
+        "ChannelArn": str,
+        "CreatedTimestamp": datetime,
+        "CreatedBy": "IdentityTypeDef",
     },
+    total=False,
 )
 
 ChannelSummaryTypeDef = TypedDict(
     "ChannelSummaryTypeDef",
     {
-        "Name": NotRequired[str],
-        "ChannelArn": NotRequired[str],
-        "Mode": NotRequired[ChannelModeType],
-        "Privacy": NotRequired[ChannelPrivacyType],
-        "Metadata": NotRequired[str],
-        "LastMessageTimestamp": NotRequired[datetime],
+        "Name": str,
+        "ChannelArn": str,
+        "Mode": ChannelModeType,
+        "Privacy": ChannelPrivacyType,
+        "Metadata": str,
+        "LastMessageTimestamp": datetime,
     },
+    total=False,
 )
 
 ChannelTypeDef = TypedDict(
     "ChannelTypeDef",
     {
-        "Name": NotRequired[str],
-        "ChannelArn": NotRequired[str],
-        "Mode": NotRequired[ChannelModeType],
-        "Privacy": NotRequired[ChannelPrivacyType],
-        "Metadata": NotRequired[str],
-        "CreatedBy": NotRequired["IdentityTypeDef"],
-        "CreatedTimestamp": NotRequired[datetime],
-        "LastMessageTimestamp": NotRequired[datetime],
-        "LastUpdatedTimestamp": NotRequired[datetime],
-        "ChannelFlowArn": NotRequired[str],
+        "Name": str,
+        "ChannelArn": str,
+        "Mode": ChannelModeType,
+        "Privacy": ChannelPrivacyType,
+        "Metadata": str,
+        "CreatedBy": "IdentityTypeDef",
+        "CreatedTimestamp": datetime,
+        "LastMessageTimestamp": datetime,
+        "LastUpdatedTimestamp": datetime,
+        "ChannelFlowArn": str,
     },
+    total=False,
 )
 
 CreateChannelBanRequestRequestTypeDef = TypedDict(
@@ -435,16 +496,29 @@ CreateChannelBanResponseTypeDef = TypedDict(
     },
 )
 
-CreateChannelFlowRequestRequestTypeDef = TypedDict(
-    "CreateChannelFlowRequestRequestTypeDef",
+_RequiredCreateChannelFlowRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateChannelFlowRequestRequestTypeDef",
     {
         "AppInstanceArn": str,
         "Processors": Sequence["ProcessorTypeDef"],
         "Name": str,
         "ClientRequestToken": str,
-        "Tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
+_OptionalCreateChannelFlowRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateChannelFlowRequestRequestTypeDef",
+    {
+        "Tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateChannelFlowRequestRequestTypeDef(
+    _RequiredCreateChannelFlowRequestRequestTypeDef, _OptionalCreateChannelFlowRequestRequestTypeDef
+):
+    pass
+
 
 CreateChannelFlowResponseTypeDef = TypedDict(
     "CreateChannelFlowResponseTypeDef",
@@ -491,19 +565,32 @@ CreateChannelModeratorResponseTypeDef = TypedDict(
     },
 )
 
-CreateChannelRequestRequestTypeDef = TypedDict(
-    "CreateChannelRequestRequestTypeDef",
+_RequiredCreateChannelRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateChannelRequestRequestTypeDef",
     {
         "AppInstanceArn": str,
         "Name": str,
         "ClientRequestToken": str,
         "ChimeBearer": str,
-        "Mode": NotRequired[ChannelModeType],
-        "Privacy": NotRequired[ChannelPrivacyType],
-        "Metadata": NotRequired[str],
-        "Tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
+_OptionalCreateChannelRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateChannelRequestRequestTypeDef",
+    {
+        "Mode": ChannelModeType,
+        "Privacy": ChannelPrivacyType,
+        "Metadata": str,
+        "Tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateChannelRequestRequestTypeDef(
+    _RequiredCreateChannelRequestRequestTypeDef, _OptionalCreateChannelRequestRequestTypeDef
+):
+    pass
+
 
 CreateChannelResponseTypeDef = TypedDict(
     "CreateChannelResponseTypeDef",
@@ -753,9 +840,10 @@ GetMessagingSessionEndpointResponseTypeDef = TypedDict(
 IdentityTypeDef = TypedDict(
     "IdentityTypeDef",
     {
-        "Arn": NotRequired[str],
-        "Name": NotRequired[str],
+        "Arn": str,
+        "Name": str,
     },
+    total=False,
 )
 
 LambdaConfigurationTypeDef = TypedDict(
@@ -766,15 +854,28 @@ LambdaConfigurationTypeDef = TypedDict(
     },
 )
 
-ListChannelBansRequestRequestTypeDef = TypedDict(
-    "ListChannelBansRequestRequestTypeDef",
+_RequiredListChannelBansRequestRequestTypeDef = TypedDict(
+    "_RequiredListChannelBansRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "ChimeBearer": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListChannelBansRequestRequestTypeDef = TypedDict(
+    "_OptionalListChannelBansRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListChannelBansRequestRequestTypeDef(
+    _RequiredListChannelBansRequestRequestTypeDef, _OptionalListChannelBansRequestRequestTypeDef
+):
+    pass
+
 
 ListChannelBansResponseTypeDef = TypedDict(
     "ListChannelBansResponseTypeDef",
@@ -786,14 +887,27 @@ ListChannelBansResponseTypeDef = TypedDict(
     },
 )
 
-ListChannelFlowsRequestRequestTypeDef = TypedDict(
-    "ListChannelFlowsRequestRequestTypeDef",
+_RequiredListChannelFlowsRequestRequestTypeDef = TypedDict(
+    "_RequiredListChannelFlowsRequestRequestTypeDef",
     {
         "AppInstanceArn": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListChannelFlowsRequestRequestTypeDef = TypedDict(
+    "_OptionalListChannelFlowsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListChannelFlowsRequestRequestTypeDef(
+    _RequiredListChannelFlowsRequestRequestTypeDef, _OptionalListChannelFlowsRequestRequestTypeDef
+):
+    pass
+
 
 ListChannelFlowsResponseTypeDef = TypedDict(
     "ListChannelFlowsResponseTypeDef",
@@ -804,15 +918,29 @@ ListChannelFlowsResponseTypeDef = TypedDict(
     },
 )
 
-ListChannelMembershipsForAppInstanceUserRequestRequestTypeDef = TypedDict(
-    "ListChannelMembershipsForAppInstanceUserRequestRequestTypeDef",
+_RequiredListChannelMembershipsForAppInstanceUserRequestRequestTypeDef = TypedDict(
+    "_RequiredListChannelMembershipsForAppInstanceUserRequestRequestTypeDef",
     {
         "ChimeBearer": str,
-        "AppInstanceUserArn": NotRequired[str],
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListChannelMembershipsForAppInstanceUserRequestRequestTypeDef = TypedDict(
+    "_OptionalListChannelMembershipsForAppInstanceUserRequestRequestTypeDef",
+    {
+        "AppInstanceUserArn": str,
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListChannelMembershipsForAppInstanceUserRequestRequestTypeDef(
+    _RequiredListChannelMembershipsForAppInstanceUserRequestRequestTypeDef,
+    _OptionalListChannelMembershipsForAppInstanceUserRequestRequestTypeDef,
+):
+    pass
+
 
 ListChannelMembershipsForAppInstanceUserResponseTypeDef = TypedDict(
     "ListChannelMembershipsForAppInstanceUserResponseTypeDef",
@@ -823,16 +951,30 @@ ListChannelMembershipsForAppInstanceUserResponseTypeDef = TypedDict(
     },
 )
 
-ListChannelMembershipsRequestRequestTypeDef = TypedDict(
-    "ListChannelMembershipsRequestRequestTypeDef",
+_RequiredListChannelMembershipsRequestRequestTypeDef = TypedDict(
+    "_RequiredListChannelMembershipsRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "ChimeBearer": str,
-        "Type": NotRequired[ChannelMembershipTypeType],
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListChannelMembershipsRequestRequestTypeDef = TypedDict(
+    "_OptionalListChannelMembershipsRequestRequestTypeDef",
+    {
+        "Type": ChannelMembershipTypeType,
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListChannelMembershipsRequestRequestTypeDef(
+    _RequiredListChannelMembershipsRequestRequestTypeDef,
+    _OptionalListChannelMembershipsRequestRequestTypeDef,
+):
+    pass
+
 
 ListChannelMembershipsResponseTypeDef = TypedDict(
     "ListChannelMembershipsResponseTypeDef",
@@ -844,18 +986,32 @@ ListChannelMembershipsResponseTypeDef = TypedDict(
     },
 )
 
-ListChannelMessagesRequestRequestTypeDef = TypedDict(
-    "ListChannelMessagesRequestRequestTypeDef",
+_RequiredListChannelMessagesRequestRequestTypeDef = TypedDict(
+    "_RequiredListChannelMessagesRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "ChimeBearer": str,
-        "SortOrder": NotRequired[SortOrderType],
-        "NotBefore": NotRequired[Union[datetime, str]],
-        "NotAfter": NotRequired[Union[datetime, str]],
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListChannelMessagesRequestRequestTypeDef = TypedDict(
+    "_OptionalListChannelMessagesRequestRequestTypeDef",
+    {
+        "SortOrder": SortOrderType,
+        "NotBefore": Union[datetime, str],
+        "NotAfter": Union[datetime, str],
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListChannelMessagesRequestRequestTypeDef(
+    _RequiredListChannelMessagesRequestRequestTypeDef,
+    _OptionalListChannelMessagesRequestRequestTypeDef,
+):
+    pass
+
 
 ListChannelMessagesResponseTypeDef = TypedDict(
     "ListChannelMessagesResponseTypeDef",
@@ -867,15 +1023,29 @@ ListChannelMessagesResponseTypeDef = TypedDict(
     },
 )
 
-ListChannelModeratorsRequestRequestTypeDef = TypedDict(
-    "ListChannelModeratorsRequestRequestTypeDef",
+_RequiredListChannelModeratorsRequestRequestTypeDef = TypedDict(
+    "_RequiredListChannelModeratorsRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "ChimeBearer": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListChannelModeratorsRequestRequestTypeDef = TypedDict(
+    "_OptionalListChannelModeratorsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListChannelModeratorsRequestRequestTypeDef(
+    _RequiredListChannelModeratorsRequestRequestTypeDef,
+    _OptionalListChannelModeratorsRequestRequestTypeDef,
+):
+    pass
+
 
 ListChannelModeratorsResponseTypeDef = TypedDict(
     "ListChannelModeratorsResponseTypeDef",
@@ -887,14 +1057,28 @@ ListChannelModeratorsResponseTypeDef = TypedDict(
     },
 )
 
-ListChannelsAssociatedWithChannelFlowRequestRequestTypeDef = TypedDict(
-    "ListChannelsAssociatedWithChannelFlowRequestRequestTypeDef",
+_RequiredListChannelsAssociatedWithChannelFlowRequestRequestTypeDef = TypedDict(
+    "_RequiredListChannelsAssociatedWithChannelFlowRequestRequestTypeDef",
     {
         "ChannelFlowArn": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListChannelsAssociatedWithChannelFlowRequestRequestTypeDef = TypedDict(
+    "_OptionalListChannelsAssociatedWithChannelFlowRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListChannelsAssociatedWithChannelFlowRequestRequestTypeDef(
+    _RequiredListChannelsAssociatedWithChannelFlowRequestRequestTypeDef,
+    _OptionalListChannelsAssociatedWithChannelFlowRequestRequestTypeDef,
+):
+    pass
+
 
 ListChannelsAssociatedWithChannelFlowResponseTypeDef = TypedDict(
     "ListChannelsAssociatedWithChannelFlowResponseTypeDef",
@@ -905,15 +1089,29 @@ ListChannelsAssociatedWithChannelFlowResponseTypeDef = TypedDict(
     },
 )
 
-ListChannelsModeratedByAppInstanceUserRequestRequestTypeDef = TypedDict(
-    "ListChannelsModeratedByAppInstanceUserRequestRequestTypeDef",
+_RequiredListChannelsModeratedByAppInstanceUserRequestRequestTypeDef = TypedDict(
+    "_RequiredListChannelsModeratedByAppInstanceUserRequestRequestTypeDef",
     {
         "ChimeBearer": str,
-        "AppInstanceUserArn": NotRequired[str],
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListChannelsModeratedByAppInstanceUserRequestRequestTypeDef = TypedDict(
+    "_OptionalListChannelsModeratedByAppInstanceUserRequestRequestTypeDef",
+    {
+        "AppInstanceUserArn": str,
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListChannelsModeratedByAppInstanceUserRequestRequestTypeDef(
+    _RequiredListChannelsModeratedByAppInstanceUserRequestRequestTypeDef,
+    _OptionalListChannelsModeratedByAppInstanceUserRequestRequestTypeDef,
+):
+    pass
+
 
 ListChannelsModeratedByAppInstanceUserResponseTypeDef = TypedDict(
     "ListChannelsModeratedByAppInstanceUserResponseTypeDef",
@@ -924,16 +1122,29 @@ ListChannelsModeratedByAppInstanceUserResponseTypeDef = TypedDict(
     },
 )
 
-ListChannelsRequestRequestTypeDef = TypedDict(
-    "ListChannelsRequestRequestTypeDef",
+_RequiredListChannelsRequestRequestTypeDef = TypedDict(
+    "_RequiredListChannelsRequestRequestTypeDef",
     {
         "AppInstanceArn": str,
         "ChimeBearer": str,
-        "Privacy": NotRequired[ChannelPrivacyType],
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListChannelsRequestRequestTypeDef = TypedDict(
+    "_OptionalListChannelsRequestRequestTypeDef",
+    {
+        "Privacy": ChannelPrivacyType,
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListChannelsRequestRequestTypeDef(
+    _RequiredListChannelsRequestRequestTypeDef, _OptionalListChannelsRequestRequestTypeDef
+):
+    pass
+
 
 ListChannelsResponseTypeDef = TypedDict(
     "ListChannelsResponseTypeDef",
@@ -962,15 +1173,17 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 MessageAttributeValueTypeDef = TypedDict(
     "MessageAttributeValueTypeDef",
     {
-        "StringValues": NotRequired[Sequence[str]],
+        "StringValues": Sequence[str],
     },
+    total=False,
 )
 
 MessagingSessionEndpointTypeDef = TypedDict(
     "MessagingSessionEndpointTypeDef",
     {
-        "Url": NotRequired[str],
+        "Url": str,
     },
+    total=False,
 )
 
 ProcessorConfigurationTypeDef = TypedDict(
@@ -993,19 +1206,33 @@ ProcessorTypeDef = TypedDict(
 PushNotificationConfigurationTypeDef = TypedDict(
     "PushNotificationConfigurationTypeDef",
     {
-        "Title": NotRequired[str],
-        "Body": NotRequired[str],
-        "Type": NotRequired[PushNotificationTypeType],
+        "Title": str,
+        "Body": str,
+        "Type": PushNotificationTypeType,
     },
+    total=False,
 )
 
-PushNotificationPreferencesTypeDef = TypedDict(
-    "PushNotificationPreferencesTypeDef",
+_RequiredPushNotificationPreferencesTypeDef = TypedDict(
+    "_RequiredPushNotificationPreferencesTypeDef",
     {
         "AllowNotifications": AllowNotificationsType,
-        "FilterRule": NotRequired[str],
     },
 )
+_OptionalPushNotificationPreferencesTypeDef = TypedDict(
+    "_OptionalPushNotificationPreferencesTypeDef",
+    {
+        "FilterRule": str,
+    },
+    total=False,
+)
+
+
+class PushNotificationPreferencesTypeDef(
+    _RequiredPushNotificationPreferencesTypeDef, _OptionalPushNotificationPreferencesTypeDef
+):
+    pass
+
 
 PutChannelMembershipPreferencesRequestRequestTypeDef = TypedDict(
     "PutChannelMembershipPreferencesRequestRequestTypeDef",
@@ -1056,8 +1283,8 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-SendChannelMessageRequestRequestTypeDef = TypedDict(
-    "SendChannelMessageRequestRequestTypeDef",
+_RequiredSendChannelMessageRequestRequestTypeDef = TypedDict(
+    "_RequiredSendChannelMessageRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "Content": str,
@@ -1065,11 +1292,25 @@ SendChannelMessageRequestRequestTypeDef = TypedDict(
         "Persistence": ChannelMessagePersistenceTypeType,
         "ClientRequestToken": str,
         "ChimeBearer": str,
-        "Metadata": NotRequired[str],
-        "PushNotification": NotRequired["PushNotificationConfigurationTypeDef"],
-        "MessageAttributes": NotRequired[Mapping[str, "MessageAttributeValueTypeDef"]],
     },
 )
+_OptionalSendChannelMessageRequestRequestTypeDef = TypedDict(
+    "_OptionalSendChannelMessageRequestRequestTypeDef",
+    {
+        "Metadata": str,
+        "PushNotification": "PushNotificationConfigurationTypeDef",
+        "MessageAttributes": Mapping[str, "MessageAttributeValueTypeDef"],
+    },
+    total=False,
+)
+
+
+class SendChannelMessageRequestRequestTypeDef(
+    _RequiredSendChannelMessageRequestRequestTypeDef,
+    _OptionalSendChannelMessageRequestRequestTypeDef,
+):
+    pass
+
 
 SendChannelMessageResponseTypeDef = TypedDict(
     "SendChannelMessageResponseTypeDef",
@@ -1122,16 +1363,30 @@ UpdateChannelFlowResponseTypeDef = TypedDict(
     },
 )
 
-UpdateChannelMessageRequestRequestTypeDef = TypedDict(
-    "UpdateChannelMessageRequestRequestTypeDef",
+_RequiredUpdateChannelMessageRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateChannelMessageRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "MessageId": str,
         "ChimeBearer": str,
-        "Content": NotRequired[str],
-        "Metadata": NotRequired[str],
     },
 )
+_OptionalUpdateChannelMessageRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateChannelMessageRequestRequestTypeDef",
+    {
+        "Content": str,
+        "Metadata": str,
+    },
+    total=False,
+)
+
+
+class UpdateChannelMessageRequestRequestTypeDef(
+    _RequiredUpdateChannelMessageRequestRequestTypeDef,
+    _OptionalUpdateChannelMessageRequestRequestTypeDef,
+):
+    pass
+
 
 UpdateChannelMessageResponseTypeDef = TypedDict(
     "UpdateChannelMessageResponseTypeDef",
@@ -1159,16 +1414,29 @@ UpdateChannelReadMarkerResponseTypeDef = TypedDict(
     },
 )
 
-UpdateChannelRequestRequestTypeDef = TypedDict(
-    "UpdateChannelRequestRequestTypeDef",
+_RequiredUpdateChannelRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateChannelRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "Name": str,
         "Mode": ChannelModeType,
         "ChimeBearer": str,
-        "Metadata": NotRequired[str],
     },
 )
+_OptionalUpdateChannelRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateChannelRequestRequestTypeDef",
+    {
+        "Metadata": str,
+    },
+    total=False,
+)
+
+
+class UpdateChannelRequestRequestTypeDef(
+    _RequiredUpdateChannelRequestRequestTypeDef, _OptionalUpdateChannelRequestRequestTypeDef
+):
+    pass
+
 
 UpdateChannelResponseTypeDef = TypedDict(
     "UpdateChannelResponseTypeDef",
